@@ -1,7 +1,4 @@
 # encoding: utf-8
-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from django.db import models
 
 
@@ -9,7 +6,7 @@ class Foo(models.Model):
     title = models.CharField(max_length=255)
     body = models.TextField()
 
-    def __unicode__(self):
+    def __str__(self):
         return self.title
 
 
@@ -17,5 +14,5 @@ class Bar(models.Model):
     author = models.CharField(max_length=255)
     content = models.TextField()
 
-    def __unicode__(self):
+    def __str__(self):
         return self.author
