@@ -1,7 +1,4 @@
 # encoding: utf-8
-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from haystack import indexes
 
 from .models import Checkin
@@ -9,16 +6,16 @@ from .models import Checkin
 
 class CheckinSearchIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(document=True)
-    username = indexes.CharField(model_attr='username')
-    comment = indexes.CharField(model_attr='comment')
+    username = indexes.CharField(model_attr="username")
+    comment = indexes.CharField(model_attr="comment")
     # Again, if you were using GeoDjango, this could be just:
     #   location = indexes.LocationField(model_attr='location')
-    location = indexes.LocationField(model_attr='get_location')
-    created = indexes.DateTimeField(model_attr='created')
+    location = indexes.LocationField(model_attr="get_location")
+    created = indexes.DateTimeField(model_attr="created")
 
     def get_model(self):
         return Checkin
 
     def prepare_text(self, obj):
         # Because I don't feel like creating a template just for this.
-        return '\n'.join([obj.comment, obj.username])
+        return "\n".join([obj.comment, obj.username])
